@@ -33,7 +33,7 @@ static inline VList * copy_arg_file(const VList *drive_list, const char src[], c
 static inline VList * copy_arg_dir(const char *tmp_src, const char *tmp_dst, const _Bool src_current_flag, const VList *drive_list, const OPArg *, const SDir *, CPInfo *, CPDD *, VList *file_list);
 static void check_overwrite(const OPArg *, const SDir *, CPInfo *, CPDD *);
 static void check_write_file_or_create_link(const OPArg *, const SDir *, CPInfo *, CPDD *);
-static inline _Bool check_this_dir(const CPInfo *cpinfo, const char *this_dir);
+static inline _Bool check_parent(const char *src, const char *dst);
 static inline struct stat * make_directory(const OPArg *, CPInfo *, CPDD *);
 static VList * dir_traverse(const OPArg *, const SDir *, VList *file_list, CPInfo *, CPDD *);
 static inline void delete_last_slash(const int len, char []);
@@ -45,7 +45,7 @@ static inline void count_plus_dir(CPInfo *, CPDD *);
 static inline void ch_time_and_mod_dir(const CPInfo *, const struct stat *, CPDD *);
 static inline void clean(const char buf[], const int len);
 static inline void fgets_is_null(void);
-static inline void check_set_same_or_different(const VList *drive_list, const char *src, const char *dst, const OPArg *, CPInfo *);
+static inline void set_same_or_different(const VList *drive_list, const char *src, const char *dst, const OPArg *, CPInfo *);
 
 /*******************************************************************************
 *******************************************************************************/
@@ -385,7 +385,7 @@ static inline VList * copy_arg_link(const OPArg *oparg, const SDir *sdir, CPInfo
 static inline VList * copy_arg_file(const VList *drive_list, const char tmp_src[], const char tmp_dst[], const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd, VList *file_list)
 {
 	count_plus_file(cpinfo, cpdd);
-	check_set_same_or_different(drive_list, tmp_src, tmp_dst, oparg, cpinfo);
+	set_same_or_different(drive_list, tmp_src, tmp_dst, oparg, cpinfo);
 	check_overwrite(oparg, sdir, cpinfo, cpdd);
 	file_list = append_list((void *)cpinfo, file_list);
 	return file_list;
@@ -395,90 +395,18 @@ static inline VList * copy_arg_file(const VList *drive_list, const char tmp_src[
 *******************************************************************************/
 static inline VList * copy_arg_dir(const char *tmp_src, const char *tmp_dst, const _Bool src_current_flag, const VList *drive_list, const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd, VList *file_list)
 {
-	const char *s = tmp_src;
-	const char *d = tmp_dst;
-	_Bool parent_flag = false;
+	_Bool parent_flag = check_parent(tmp_src, tmp_dst);
 
-	for(;;)
+	if(parent_flag == true)
 	{
-		if(*s == *d)
+		if(src_current_flag == true)
 		{
-			if(*s == '\0')
-			{
-				parent_flag = true;
-				break;
-			}
-
-			s++;
-			d++;
+			fprintf(stderr, "`.' をスキップします\n");
 		}
-		else if((*s == '\0') && (*d == G_DIR_SEPARATOR))
+		else
 		{
-			parent_flag = true;
-			break;
+			fprintf(stderr, "`%s' をスキップします\n", cpinfo->src);
 		}
-		else 
-		{
-			break;
-		}
-	}
-
-	/* cmpはstrcmpのcmp */
-	_Bool cmp_flag = false;
-
-	if(src_current_flag == true)
-	{
-		char *s = cpinfo->src;
-		char *d = cpinfo->dst;
-		int s_len = strlen(s);
-		int d_len = strlen(d);
-
-		if(s_len == d_len)
-		{
-			if(strcmp(s, d) == 0)
-			{
-				cmp_flag = true;
-			}
-		}
-		else if(s_len < d_len)
-		{
-			for(;;)
-			{
-				if(*s == *d)
-				{
-					s++;
-					d++;
-				}
-				else
-				{
-					break;
-				}
-
-				if(*s == '\0')
-				{
-					if(*d == G_DIR_SEPARATOR)
-					{
-						cmp_flag = true;
-					}
-					break;
-				}
-			}
-		}
-	}
-
-	if(cmp_flag == true)
-	{
-		fprintf(stderr, "`.' をスキップします\n");
-
-		if(cpinfo->src != NULL) free(cpinfo->src);
-		if(cpinfo->dst != NULL) free(cpinfo->dst);
-
-		free(cpinfo);
-		cpinfo = NULL;
-	}
-	else if(parent_flag == true)
-	{
-		fprintf(stderr, "`%s' をスキップします\n", cpinfo->src);
 
 		if(cpinfo->src != NULL) free(cpinfo->src);
 		if(cpinfo->dst != NULL) free(cpinfo->dst);
@@ -488,7 +416,7 @@ static inline VList * copy_arg_dir(const char *tmp_src, const char *tmp_dst, con
 	}
 	else
 	{
-		check_set_same_or_different(drive_list, tmp_src, tmp_dst, oparg, cpinfo);
+		set_same_or_different(drive_list, tmp_src, tmp_dst, oparg, cpinfo);
 
 		struct stat *stat_buf;
 
@@ -656,7 +584,7 @@ INPUT:
 
 			case THIS_DIR_YES:
 				{
-					_Bool b = check_this_dir(cpinfo, this_dir);
+					_Bool b = check_parent(this_dir, cpinfo->dst);
 
 					if(b == true)
 					{
@@ -674,7 +602,7 @@ INPUT:
 
 			case THIS_DIR_NO:
 				{
-					_Bool b = check_this_dir(cpinfo, this_dir);
+					_Bool b = check_parent(this_dir, cpinfo->dst);
 
 					if(b == true)
 					{
@@ -743,49 +671,34 @@ static void check_write_file_or_create_link(const OPArg *oparg, const SDir *sdir
 
 /*******************************************************************************
 *******************************************************************************/
-static inline _Bool check_this_dir(const CPInfo *cpinfo, const char *this_dir)
+static inline _Bool check_parent(const char *src, const char *dst)
 {
-	char *tmp = g_path_get_dirname(cpinfo->dst);
-	char *tmp_free = tmp;
-	const char *tmp2 = this_dir;
-	int tmp_len = strlen(tmp);
-	int this_len = strlen(tmp2);
 	_Bool flag = false;
 
-	if(this_len == tmp_len)
+	for(;;)
 	{
-		if(strcmp(tmp2, tmp) == 0)
+		if(*src == *dst)
+		{
+			if(*src == '\0')
+			{
+				flag = true;
+				break;
+			}
+
+			src++;
+			dst++;
+		}
+		else if((*src == '\0') && (*dst == G_DIR_SEPARATOR))
 		{
 			flag = true;
+			break;
 		}
-	}
-	else if(this_len < tmp_len)
-	{
-		for(;;)
+		else 
 		{
-			if(*tmp2 == *tmp)
-			{
-				tmp2++;
-				tmp++;
-			}
-			else
-			{
-				break;
-			}
-
-			if(*tmp2 == '\0')
-			{
-				if(*tmp == G_DIR_SEPARATOR)
-				{
-					flag = true;
-				}
-				break;
-			}
+			break;
 		}
 	}
 
-	free(tmp_free);
-
 	return flag ? true : false;
 }
 
@@ -1172,7 +1085,7 @@ for(;;)\
 /******************************************************************************
  * ドライブが同一かどうか調べる
 *******************************************************************************/
-static inline void check_set_same_or_different(const VList *drive_list, const char *src, const char *dst, const OPArg *oparg, CPInfo *cpinfo)
+static inline void set_same_or_different(const VList *drive_list, const char *src, const char *dst, const OPArg *oparg, CPInfo *cpinfo)
 {
 	/*
 	 * キャストしないと警告が出る
@@ -1186,6 +1099,7 @@ static inline void check_set_same_or_different(const VList *drive_list, const ch
 	{
 		DPath *tmp = (DPath *)tmplist->data;
 
+		/* /の処理 */
 		if((tmp->mount_point[1] == '\0') && (tmp->mount_point[0] == G_DIR_SEPARATOR))
 		{
 			if(srcdev == NULL)
