@@ -3,7 +3,7 @@
 
 #define _GNU_SOURCE
 
-#include "ch_time_and_mod_link.h" // inline
+#include "ch_time_and_mod_link.h"
 #include "struct_CPDD.h"
 #include "struct_OPArg.h"
 
@@ -19,12 +19,13 @@
 	cpinfo->dst_para = INITIAL;
 
 /* 関数プロトタイプ */
-static inline void create_symboliclink(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd);
-static inline _Bool c_s(const OPArg *oparg, const CPInfo *cpinfo, CPDD *cpdd);
+static void create_symboliclink(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd);
+static _Bool c_s(const OPArg *oparg, const CPInfo *cpinfo, CPDD *cpdd);
+
 /*******************************************************************************
 シンボリックリンクを作成
 *******************************************************************************/
-static inline void create_symboliclink(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
+static void create_symboliclink(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 {
 	_Bool check;
 	struct stat stat_src;
@@ -142,7 +143,7 @@ static inline void create_symboliclink(const OPArg *oparg, CPInfo *cpinfo, CPDD
 
 /*******************************************************************************
 *******************************************************************************/
-static inline _Bool c_s(const OPArg *oparg, const CPInfo *cpinfo, CPDD *cpdd)
+static _Bool c_s(const OPArg *oparg, const CPInfo *cpinfo, CPDD *cpdd)
 {
 	int readlink_len;
 	char link_buf[PATH_MAX];
