@@ -115,7 +115,7 @@ static void o_direct(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD
 			fprintf(stderr, "ベリファイに失敗しました\n");
 			fprintf(stderr, "`%s'\n", cpinfo->dst);
 			print_error("posix_memalign", __FILE__, __LINE__, cpdd);
-			write_log_hash_check(cpinfo, cpinfo->src_md5, "NULL", sdir, cpdd, false);
+			write_log_hash_check(cpinfo, oparg, cpinfo->src_md5, "NULL", sdir, cpdd, false);
 
 			if(buf[0] != NULL)
 			{
@@ -187,14 +187,18 @@ static void o_direct(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD
 
 			if(oparg->V == VERBOS)
 			{
-				printf("%s : %s\n", cpinfo->src_md5, cpinfo->src);
+				if(oparg->M == NOT)
+				{
+					printf("%s : %s\n", cpinfo->src_md5, cpinfo->src);
+				}
+
 				printf("%s : %s\n", hex_output, cpinfo->dst);
 				fflush(stdout);
 			}
 
 			if(oparg->L == LOG)
 			{
-				write_log_hash_check(cpinfo, cpinfo->src_md5, hex_output, sdir, cpdd, true);
+				write_log_hash_check(cpinfo, oparg, cpinfo->src_md5, hex_output, sdir, cpdd, true);
 			}
 		}
 		else if(cpinfo->src_size > total)
@@ -211,7 +215,7 @@ static void o_direct(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD
 		if(unlink_miss_file == true)
 		{
 			print_error("NODATA", __FILE__, __LINE__, cpdd);
-			write_log_hash_check(cpinfo, cpinfo->src_md5, hex_output, sdir, cpdd, false);
+			write_log_hash_check(cpinfo, oparg, cpinfo->src_md5, hex_output, sdir, cpdd, false);
 			cpinfo->dst_para = DELETE;
 			fprintf(stderr, "`%s' を削除します\n", cpinfo->dst);
 
@@ -229,7 +233,7 @@ static void o_direct(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD
 		fprintf(stderr, "ベリファイ出来ません\n");
 		fprintf(stderr, "メモリの確保に失敗しました\n");
 		print_error("NODATA", __FILE__, __LINE__, cpdd);
-		write_log_hash_check(cpinfo, cpinfo->src_md5, "NULL", sdir, cpdd, false);
+		write_log_hash_check(cpinfo, oparg, cpinfo->src_md5, "NULL", sdir, cpdd, false);
 		cpinfo->dst_para = INITIAL;
 		break;
 	}
