@@ -96,14 +96,18 @@ void verify_md5sum(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *c
 
 				if(oparg->V == VERBOS)
 				{
-					printf("%s : %s\n", cpinfo->src_md5, cpinfo->src);
+					if(oparg->M == NOT)
+					{
+						printf("%s : %s\n", cpinfo->src_md5, cpinfo->src);
+					}
+
 					printf("%s : %s\n", ddst, cpinfo->dst);
 					fflush(stdout);
 				}
 
 				if(oparg->L == LOG)
 				{
-					write_log_hash_check(cpinfo, cpinfo->src_md5, ddst, sdir, cpdd, true);
+					write_log_hash_check(cpinfo, oparg, cpinfo->src_md5, ddst, sdir, cpdd, true);
 				}
 			}
 			else
@@ -111,7 +115,7 @@ void verify_md5sum(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *c
 				fprintf(stderr, "ハッシュ値が一致しませんでした\n");
 				fprintf(stderr, "`%s' を削除します\n", cpinfo->dst);
 				print_error("NODATA", __FILE__, __LINE__, cpdd);
-				write_log_hash_check(cpinfo, cpinfo->src_md5, ddst, sdir, cpdd, false);
+				write_log_hash_check(cpinfo, oparg, cpinfo->src_md5, ddst, sdir, cpdd, false);
 				cpinfo->dst_para = DELETE;
 
 				errno = 0;
@@ -127,7 +131,7 @@ void verify_md5sum(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *c
 			print_error("NODATA", __FILE__, __LINE__, cpdd);
 			fprintf(stderr, "ベリファイに失敗しました\n");
 			fprintf(stderr, "`%s'\n", cpinfo->dst);
-			write_log_hash_check(cpinfo, "NULL", "NULL", sdir, cpdd, false);
+			write_log_hash_check(cpinfo, oparg, "NULL", "NULL", sdir, cpdd, false);
 		}
 	}
 	else
@@ -135,7 +139,7 @@ void verify_md5sum(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *c
 		print_error("NODATA", __FILE__, __LINE__, cpdd);
 		fprintf(stderr, "ベリファイに失敗しました\n");
 		fprintf(stderr, "`%s'\n", cpinfo->dst);
-		write_log_hash_check(cpinfo, "NULL", "NULL", sdir, cpdd, false);
+		write_log_hash_check(cpinfo, oparg, "NULL", "NULL", sdir, cpdd, false);
 	}
 
 	/* 念のため、pipe詰まり対策 */
